@@ -48,8 +48,8 @@
 
 #include <QDebug>
 #include <QGuiApplication>
-#include <QtCore/QFileInfo>
-#include <QtCore/QDir>
+#include <QFileInfo>
+#include <QDir>
 #include <QStandardPaths>
 #include <QThread>
 #include <QLibraryInfo>
@@ -135,7 +135,11 @@ void KCrash::initialize()
         qCDebug(LOG_KCRASH) << "KCrash disabled through environment.";
     }
 
-    KCrash::setApplicationFilePath(QCoreApplication::applicationFilePath());
+    if (QCoreApplication::instance()) {
+        KCrash::setApplicationFilePath(QCoreApplication::applicationFilePath());
+    } else {
+        qWarning() << "This process needs a QCoreApplication instance in order to use KCrash";
+    }
 
     s_coreConfig(); // Initialize.
 }
@@ -174,7 +178,7 @@ public:
         startTimer(10000); // 10 s
     }
 protected:
-    void timerEvent(QTimerEvent *event) Q_DECL_OVERRIDE
+    void timerEvent(QTimerEvent *event) override 
     {
         if (!s_crashHandler) { // not set meanwhile
             KCrash::setCrashHandler(KCrash::defaultCrashHandler);
